@@ -30,7 +30,7 @@ from . import logger
 
 class Homebrew(PackageManager):
 
-    """ Virutal package manager shared by brew and cask CLI defined below.
+    """Virutal package manager shared by brew and cask CLI defined below.
 
     Homebrew is the umbrella project providing both brew and brew cask
     commands.
@@ -46,7 +46,7 @@ class Homebrew(PackageManager):
     cli_name = None
 
     def get_version(self):
-        """ Fetch version from ``brew --version`` output.
+        """Fetch version from ``brew --version`` output.
 
         .. code-block:: shell-session
 
@@ -61,7 +61,7 @@ class Homebrew(PackageManager):
             return parse_version(output.split()[1])
 
     def sync(self):
-        """ `brew` and `cask` share the same command.
+        """`brew` and `cask` share the same command.
 
         .. code-block:: shell-session
 
@@ -73,7 +73,7 @@ class Homebrew(PackageManager):
 
     @property
     def installed(self):
-        """ Fetch installed packages from ``brew list`` output.
+        """Fetch installed packages from ``brew list`` output.
 
         .. note::
 
@@ -236,7 +236,7 @@ class Homebrew(PackageManager):
         return installed
 
     def search(self, query, extended, exact):
-        """ Fetch matching packages from ``brew search`` output.
+        """Fetch matching packages from ``brew search`` output.
 
         .. code-block:: shell-session
 
@@ -321,7 +321,7 @@ class Homebrew(PackageManager):
 
     @property
     def outdated(self):
-        """ Fetch outdated packages from ``brew outdated`` output.
+        """Fetch outdated packages from ``brew outdated`` output.
 
         Raw CLI output samples:
 
@@ -372,11 +372,12 @@ class Homebrew(PackageManager):
         return outdated
 
     def upgrade_cli(self, package_id=None):
-        """ Runs:
+        """Returns the right CLI depending on weither formula or cask are
+        concerned:
 
         .. code-block:: shell-session
 
-            ► brew upgrade
+            ► brew upgrade --formula
             ==> Upgrading 2 outdated packages:
             node 13.11.0 -> 13.12.0
             sdl2 2.0.12 -> 2.0.12_1
@@ -404,8 +405,28 @@ class Homebrew(PackageManager):
             ==> node
             Bash completion has been installed to:
               /usr/local/etc/bash_completion.d
+
+        .. code-block:: shell-session
+
+            ► brew upgrade --cask
+            Updating Homebrew...
+            ==> Auto-updated Homebrew!
+            Updated Homebrew from 1654de327 to cfa03c8cc.
+            Updated 2 taps (homebrew/core and homebrew/cask).
+            ==> Casks with `auto_updates` or `version :latest` will not be upgraded
+            ==> Upgrading 1 outdated packages:
+            aerial 2.0.7 -> 2.0.8
+            ==> Upgrading aerial
+            ==> Downloading https://github.com/Aerial/download/v2.0.8/Aerial.saver.zip
+            ==> Downloading from https://65be.s3.amazonaws.com/44998092/29eb1e0
+            ==> Verifying SHA-256 checksum for Cask 'aerial'.
+            ==> Backing Screen Saver up to '/usr/local/Caskroom/Aerial.saver'.
+            ==> Removing Screen Saver '/Users/kde/Library/Screen Savers/Aerial.saver'.
+            ==> Moving Screen Saver to '/Users/kde/Library/Screen Savers/Aerial.saver'.
+            ==> Purging files for version 2.0.7 of Cask aerial
+            🍺  aerial was successfully upgraded!
         """
-        cmd = [self.cli_path, self.global_args, "upgrade"]
+        cmd = [self.cli_path] + self.upgrade_args
         if package_id:
             cmd.append(package_id)
         return cmd
@@ -414,7 +435,7 @@ class Homebrew(PackageManager):
         return self.upgrade_cli()
 
     def cleanup(self):
-        """ Scrub the cache, including downloads for even the latest versions.
+        """Scrub the cache, including downloads for even the latest versions.
 
         Note downloads for any installed formulae or casks will still not be
         deleted.
@@ -443,7 +464,7 @@ class Brew(Homebrew):
 
     @cachedproperty
     def search_args(self):
-        """ Returns arguments needed for search of Homebrew formulae.
+        """Returns arguments needed for search of Homebrew formulae.
 
         .. code-block:: shell-session
 
@@ -453,11 +474,47 @@ class Brew(Homebrew):
         """
         return [self.global_args, "search", "--formulae"]
 
+    @cachedproperty
+    def upgrade_args(self):
+        """Returns arguments needed for upgrade of Homebrew formulae.
+
+        .. code-block:: shell-session
+
+            ► brew upgrade --formula
+            ==> Upgrading 2 outdated packages:
+            node 13.11.0 -> 13.12.0
+            sdl2 2.0.12 -> 2.0.12_1
+            ==> Upgrading node 13.11.0 -> 13.12.0
+            ==> Downloading https://homebrew.bintray.com/bottles/node-13.tar.gz
+            ==> Downloading from https://akamai.bintray.com/fc/fc0bfb42fe23e960
+            ############################################################ 100.0%
+            ==> Pouring node-13.12.0.catalina.bottle.tar.gz
+            ==> Caveats
+            Bash completion has been installed to:
+              /usr/local/etc/bash_completion.d
+            ==> Summary
+            🍺  /usr/local/Cellar/node/13.12.0: 4,660 files, 60.3MB
+            Removing: /usr/local/Cellar/node/13.11.0... (4,686 files, 60.4MB)
+            ==> Upgrading sdl2 2.0.12 -> 2.0.12_1
+            ==> Downloading https://homebrew.bintray.com/bottles/sdl2-2.tar.gz
+            ==> Downloading from https://akamai.bintray.com/4d/4dcd635465d16372
+            ############################################################ 100.0%
+            ==> Pouring sdl2-2.0.12_1.catalina.bottle.tar.gz
+            🍺  /usr/local/Cellar/sdl2/2.0.12_1: 89 files, 4.7MB
+            Removing: /usr/local/Cellar/sdl2/2.0.12... (89 files, 4.7MB)
+            ==> Checking for dependents of upgraded formulae...
+            ==> No dependents found!
+            ==> Caveats
+            ==> node
+            Bash completion has been installed to:
+              /usr/local/etc/bash_completion.d
+        """
+        return [self.global_args, "upgrade", "--formula"]
+
 
 class Cask(Homebrew):
 
-    """ Cask is now part of Homebrew's core and extend it.
-    """
+    """Cask is now part of Homebrew's core and extend it."""
 
     name = "Homebrew Cask"
     cli_name = "brew"
@@ -466,7 +523,7 @@ class Cask(Homebrew):
 
     @cachedproperty
     def search_args(self):
-        """ Returns arguments needed for search of Homebrew casks.
+        """Returns arguments needed for search of Homebrew casks.
 
         .. code-block:: shell-session
 
@@ -481,7 +538,7 @@ class Cask(Homebrew):
 
     @property
     def outdated(self):
-        """ Search for outdated packages among installed one.
+        """Search for outdated packages among installed one.
 
         .. code-block:: shell-session
 
@@ -550,9 +607,28 @@ class Cask(Homebrew):
 
         return outdated
 
-    def upgrade_cli(self, package_id=None):
-        """ Install a package. """
-        cmd = [self.cli_path, self.global_args, "upgrade"]
-        if package_id:
-            cmd.append(package_id)
-        return cmd
+    @cachedproperty
+    def upgrade_args(self):
+        """Returns arguments needed for upgrade of Homebrew casks.
+
+        .. code-block:: shell-session
+
+            ► brew upgrade --cask
+            Updating Homebrew...
+            ==> Auto-updated Homebrew!
+            Updated Homebrew from 1654de327 to cfa03c8cc.
+            Updated 2 taps (homebrew/core and homebrew/cask).
+            ==> Casks with `auto_updates` or `version :latest` will not be upgraded
+            ==> Upgrading 1 outdated packages:
+            aerial 2.0.7 -> 2.0.8
+            ==> Upgrading aerial
+            ==> Downloading https://github.com/Aerial/download/v2.0.8/Aerial.saver.zip
+            ==> Downloading from https://65be.s3.amazonaws.com/44998092/29eb1e0
+            ==> Verifying SHA-256 checksum for Cask 'aerial'.
+            ==> Backing Screen Saver up to '/usr/local/Caskroom/Aerial.saver'.
+            ==> Removing Screen Saver '/Users/kde/Library/Screen Savers/Aerial.saver'.
+            ==> Moving Screen Saver to '/Users/kde/Library/Screen Savers/Aerial.saver'.
+            ==> Purging files for version 2.0.7 of Cask aerial
+            🍺  aerial was successfully upgraded!
+        """
+        return ["upgrade", "--cask"]
