@@ -24,7 +24,7 @@ from textwrap import indent
 
 import click
 import pytest
-from boltons.iterutils import flatten
+from boltons.iterutils import flatten, same
 from boltons.strutils import strip_ansi
 from boltons.tbutils import ExceptionInfo
 from click.testing import CliRunner
@@ -105,7 +105,7 @@ def print_cli_output(cmd, output):
 
 
 def run_cmd(*args):
-    """ Run a system command, print output and return results.
+    """Run a system command, print output and return results.
 
     Relies on robust ``run`` function implemented in BitBar plugin.
     """
@@ -143,7 +143,7 @@ def invoke(runner):
         # convenience. We just need to flatten and filters them out.
         args = list(filter(None.__ne__, flatten(args)))
         if args:
-            assert set(map(type, args)) == {str}
+            assert same(map(type, args), str)
 
         result = runner.invoke(cli, args, color=color)
 
@@ -165,7 +165,7 @@ def invoke(runner):
 
 @pytest.fixture(scope="class")
 def subcmd():
-    """ Fixture used in `test_cli_*.py` files to set the sub-command in all CLI
+    """Fixture used in `test_cli_*.py` files to set the sub-command in all CLI
     calls.
 
     Must returns a string or an iterable of strings. Defaults to `None`, which
