@@ -19,8 +19,11 @@
 
 # pylint: disable=redefined-outer-name
 
+import re
+
 import pytest
 import simplejson as json
+from boltons.iterutils import same
 
 from .conftest import MANAGER_IDS, unless_macos
 from .test_cli import CLISubCommandTests, CLITableTests
@@ -58,7 +61,7 @@ class TestSearch(CLISubCommandTests, CLITableTests):
 
             assert isinstance(info["errors"], list)
             if info["errors"]:
-                assert set(map(type, info["errors"])) == {str}
+                assert same(map(type, info["errors"]), str)
 
             assert info["id"] == manager_id
 
@@ -88,40 +91,53 @@ class TestSearch(CLISubCommandTests, CLITableTests):
         assert "ubersicht" in result.stdout
         assert "Übersicht" not in result.stdout
 
-    def test_exact_search_tokenizer(self, invoke):
+    def test_exact_search_tokenizer_one_result(self, invoke):
         result = invoke("--manager", "pip", "search", "--exact", "sed", color=False)
         assert result.exit_code == 0
         assert "1 package total" in result.stdout
         assert " sed " in result.stdout
 
-        for query in ["SED", "SeD", "sEd*", "*sED*", "_seD-@", "", "_"]:
-            result = invoke("--manager", "pip", "search", "--exact", query)
-            assert result.exit_code == 0
-            assert "0 package total" in result.stdout
-            assert "sed" not in result.stdout
+    @pytest.mark.parametrize(
+        "query", ["SED", "SeD", "sEd*", "*sED*", "_seD-@", "", "_"]
+    )
+    def test_exact_search_tokenizer_no_result(self, invoke, query):
+        result = invoke("--manager", "pip", "search", "--exact", query)
+        assert result.exit_code == 0
+        assert "0 package total" in result.stdout
+        assert "sed" not in result.stdout
 
-    def test_fuzzy_search_tokenizer(self, invoke):
-        for query in ["", "_", "_seD-@"]:
-            result = invoke("--manager", "pip", "search", query)
-            assert result.exit_code == 0
-            assert "0 package total" in result.stdout
-            assert "sed" not in result.stdout
+    @pytest.mark.parametrize("query", ["", "_", "_seD-@"])
+    def test_fuzzy_search_tokenizer_no_results(self, invoke, query):
+        result = invoke("--manager", "pip", "search", query)
+        assert result.exit_code == 0
+        assert "0 package total" in result.stdout
+        assert "sed" not in result.stdout
 
-        for query in ["sed", "SED", "SeD", "sEd*", "*sED*"]:
-            result = invoke("--manager", "pip", "search", query, color=False)
-            assert result.exit_code == 0
-            assert "2 packages total" in result.stdout
-            assert " sed " in result.stdout
-            assert " SED-cli " in result.stdout
+    @pytest.mark.parametrize("query", ["sed", "SED", "SeD", "sEd*", "*sED*"])
+    def test_fuzzy_search_tokenizer_multiple_results(self, invoke, query):
+        result = invoke("--manager", "pip", "search", query, color=False)
+        assert result.exit_code == 0
+        assert "2 packages total" in result.stdout
+        assert " sed " in result.stdout
+        assert " SED-cli " in result.stdout
 
-    def test_extended_search_tokenizer(self, invoke):
-        for query in ["", "_", "_seD-@"]:
-            result = invoke("--manager", "pip", "search", "--extended", query)
-            assert result.exit_code == 0
-            assert "0 package total" in result.stdout
-            assert "sed" not in result.stdout
+    @pytest.mark.parametrize("query", ["", "_", "_seD-@"])
+    def test_extended_search_tokenizeri_no_results(self, invoke, query):
+        result = invoke("--manager", "pip", "search", "--extended", query)
+        assert result.exit_code == 0
+        assert "0 package total" in result.stdout
+        assert "sed" not in result.stdout
 
-        for query in ["sed", "SED", "SeD", "sEd*", "*sED*"]:
-            result = invoke("--manager", "pip", "search", "--extended", query)
-            assert result.exit_code == 0
-            assert "23 packages total" in result.stdout
+    @pytest.mark.parametrize("query", ["sed", "SED", "SeD", "sEd*", "*sED*"])
+    def test_extended_search_tokenizeri_multiple_results(self, invoke, query):
+        result = invoke("--manager", "pip", "search", "--extended", query)
+        assert result.exit_code == 0
+        last_line = result.stdout.splitlines()[-1]
+        assert last_line
+        msg_match = re.match(
+            r"^([0-9]+) packages? total \(pip: ([0-9]+)\).$", last_line
+        )
+        assert msg_match
+        assert same(msg_match.groups())
+        # We should find lots of results for this package search.
+        assert int(msg_match.groups()[0]) >= 20
